@@ -2,7 +2,7 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2012 by Dominique Dumont.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -86,7 +86,7 @@ foreach my $inc (@INC) {
     }
 }
 
-my $showpostinst = "perl -I../lib -S config-edit -model Sshd -ui none -save" ;
+my $showpostinst = "perl -I../lib -S cme migrate sshd" ;
 my $postinst = $showpostinst . " -model_dir lib/Config/Model/models "
 	 . "-root_dir .  ";
 
