@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2012 by Dominique Dumont.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,57 +9,57 @@
 #
 [
   {
-    'class_description' => 'Configuration class that represents the parameters required
-to specify port forwarding in a ssh configuration.',
-    'name' => 'Ssh::PortForward',
-    'copyright' => [
-      '2009-2011 Dominique Dumont'
-    ],
     'author' => [
       'Dominique Dumont'
     ],
-    'license' => 'LGPL2',
+    'class_description' => 'Configuration class that represents the parameters required
+to specify port forwarding in a ssh configuration.',
+    'copyright' => [
+      '2009-2011 Dominique Dumont'
+    ],
     'element' => [
       'ipv6',
       {
-        'value_type' => 'boolean',
+        'description' => 'Specify if the forward is specified iwth IPv6 or IPv4',
         'type' => 'leaf',
-        'description' => 'Specify if the forward is specified iwth IPv6 or IPv4'
+        'value_type' => 'boolean'
       },
       'bind_address',
       {
-        'value_type' => 'uniline',
-        'summary' => 'bind address to listen to',
-        'type' => 'leaf',
-        'description' => "Specify the address that the port will listen to. By default, only connections coming from localhost (127.0.0.1) will be forwarded.
+        'description' => 'Specify the address that the port will listen to. By default, only connections coming from localhost (127.0.0.1) will be forwarded.
 
 By default, the local port is bound in accordance with the GatewayPorts setting. However, an explicit bind_address may be used to bind the connection to a specific address.
 
-The bind_address of \x{201c}localhost\x{201d} indicates that the listening port be bound for local use only, while an empty address or \x{2018}*\x{2019} indicates that the port should be available from all interfaces."
+The bind_address of \'localhost\' indicates that the listening port be bound for local use only, while an empty address or \'*\' indicates that the port should be available from all interfaces.',
+        'summary' => 'bind address to listen to',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
       },
       'port',
       {
-        'value_type' => 'uniline',
+        'description' => 'Listening port. Connection made to this port will be forwarded to the other side of the tunnel.',
         'mandatory' => '1',
         'type' => 'leaf',
-        'description' => 'Listening port. Connection made to this port will be forwarded to the other side of the tunnel.'
+        'value_type' => 'uniline'
       },
       'host',
       {
-        'value_type' => 'uniline',
-        'summary' => 'host name or address',
         'mandatory' => '1',
-        'type' => 'leaf'
+        'summary' => 'host name or address',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
       },
       'hostport',
       {
-        'value_type' => 'uniline',
-        'summary' => 'destination port',
+        'description' => 'Port number to connect the tunnel to.',
         'mandatory' => '1',
+        'summary' => 'destination port',
         'type' => 'leaf',
-        'description' => 'Port number to connect the tunnel to.'
+        'value_type' => 'uniline'
       }
-    ]
+    ],
+    'license' => 'LGPL2',
+    'name' => 'Ssh::PortForward'
   }
 ]
 ;
