@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2012 by Dominique Dumont.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,19 +9,27 @@
 #
 
 $model_to_test = "Sshd" ;
-$conf_file_name = 'sshd_config';
-$conf_dir = '/etc/ssh' ;
+
+my $map = {
+   'darwin' => '/etc/sshd_config',
+   'default' => '/etc/ssh/sshd_config',
+} ;
+
+my $target = $map->{$^O} || $map->{default} ;
 
 @tests = (
     { 
-        name => 'debian-671367' ,
+        name => 'debian-bug-671367' ,
+        setup => {
+            'system_sshd_config' => $map,
+        },
         load_warnings => undef , # some weird warnings pop up in Perl smoke tests with perl 5.15.9
         check => { 
             'AuthorizedKeysFile:0' => '/etc/ssh/userkeys/%u',
             'AuthorizedKeysFile:1' => '/var/lib/misc/userkeys2/%u',
         },
         file_contents_like => {
-            '/etc/ssh/sshd_config' => qr!/etc/ssh/userkeys/%u /var/lib/misc/userkeys2/%u! ,
+            $target , qr!/etc/ssh/userkeys/%u /var/lib/misc/userkeys2/%u! ,
         }
     },
 );
